@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 =head1 NAME
 
@@ -241,6 +241,14 @@ Supported built-in types are:
 
   unsignedByte
 
+  positiveInteger
+
+  negativeInteger
+
+  nonPositiveInteger
+
+  nonNegativeInteger
+
   dateTime
 
     Notes: Although dateTime correctly validates the lexical format it does not
