@@ -4,7 +4,7 @@ use warnings;
 
 use XML::Validator::Schema::Util qw(XSD _err);
 use XML::Validator::Schema::SimpleType;
-use Carp qw(croak);
+use base 'XML::Validator::Schema::Library';
 
 =head1 NAME
 
@@ -23,7 +23,7 @@ complex.
   # add a new type
   $library->add(name => 'myString',
                 ns   => 'http://my/ns',
-                type => $type_obj);
+                obj  => $type_obj);
 
   # lookup a type
   my $type = $library->find(name => 'myString',
@@ -33,37 +33,15 @@ complex.
 
 sub new {
     my $pkg = shift;
-    my $self = bless({@_}, $pkg);
+    my $self = $pkg->SUPER::new(what => 'type', @_);
     
     # load builtin simple types into XSD namespace
-    $self->{XSD()} = { %XML::Validator::Schema::SimpleType::BUILTIN };
+    $self->{stacks}{XSD()} = { %XML::Validator::Schema::SimpleType::BUILTIN };
 
     return $self;
 }
 
-sub find {
-    my ($self, %arg) = @_;
 
-    # HACK: fix when QName resolution works
-    $arg{name} =~ s!^[^:]*:!!;
-    $arg{ns} ||= XSD;
-
-    return $self->{$arg{ns}}{$arg{name}};
-}
-
-sub add {
-    my ($self, %arg) = @_;
-    croak("Missing required name paramter.") unless $arg{name};
-    
-    # HACK: fix when QName resolution works
-    $arg{name} =~ s!^\w+:!!;
-    $arg{ns} ||= XSD;
-
-    _err("Illegal attempt to redefine type '$arg{name}' ".
-         "in namespace '$arg{ns}'")
-      if exists $self->{$arg{ns}}{$arg{name}};
-    $self->{$arg{ns}}{$arg{name}} = $arg{type};
-}
 
 1;
 
